import { useParams } from 'react-router-dom';
import { useQuery } from '@tanstack/react-query';
import { Helmet } from 'react-helmet-async';
import { ExperimentDetails } from '@/components/ExperimentDetails';
import { supabase } from '@/integrations/supabase/client';
import { useToast } from '@/hooks/use-toast';
import type { Experiment } from '@/types/experiments';
import { stripHtml } from '@/lib/utils';

const ExperimentPage = () => {
  const { slug, id } = useParams<{ slug?: string; id?: string }>();
  const { toast } = useToast();
  
  const experimentIdentifier = slug || id;

  const { data: experiment, isLoading, error } = useQuery({
    queryKey: ['experiment', experimentIdentifier],
    queryFn: async () => {
      if (!experimentIdentifier) throw new Error('No experiment identifier provided');
      
      console.log('Fetching experiment with identifier:', experimentIdentifier);
      
      let query = supabase
        .from('experiments')
        .select('*')
        .not('slug', 'is', null);
      
      // Apply the appropriate filter based on whether we have a slug or id
      if (slug) {
        query = query.eq('slug', slug);
      } else if (id) {
        query = query.eq('id', id);
      }
      
      const { data, error } = await query.maybeSingle();
      
      if (error) {
        console.error('Error fetching experiment:', error);
        toast({
          title: "Error",
          description: "Failed to load experiment. Please try again.",
          variant: "destructive",
        });
        throw error;
      }
      
      if (!data) {
        console.log('No experiment found for identifier:', experimentIdentifier);
        throw new Error('Experiment not found');
      }
      
      console.log('Fetched experiment data:', data);
      return data as Experiment;
    },
    enabled: !!experimentIdentifier,
    staleTime: 1000 * 60 * 5, // 5 minutes
    gcTime: 1000 * 60 * 30, // 30 minutes
  });

  if (isLoading) {
    return (
      <div className="min-h-screen bg-background">
        <main className="container mx-auto px-4 py-24">
          <div className="animate-pulse space-y-4">
            <div className="h-8 bg-muted rounded w-1/4" />
            <div className="h-12 bg-muted rounded w-3/4" />
            <div className="h-4 bg-muted rounded w-1/2" />
          </div>
        </main>
      </div>
    );
  }

  if (error) {
    return (
      <div className="min-h-screen bg-background">
        <main className="container mx-auto px-4 py-24">
          <div className="max-w-4xl mx-auto">
            <h1 className="text-4xl font-bold text-foreground mb-4">Error Loading Experiment</h1>
            <p className="text-muted-foreground">
              {error instanceof Error ? error.message : 'An unknown error occurred'}
            </p>
          </div>
        </main>
      </div>
    );
  }

  if (!experiment) {
    return (
      <div className="min-h-screen bg-background">
        <Helmet>
          <title>Experiment Not Found | NoCodeLab</title>
          <meta name="description" content="The requested experiment could not be found." />
        </Helmet>
        <main className="container mx-auto px-4 py-24">
          <div className="max-w-4xl mx-auto">
            <h1 className="text-4xl font-bold text-foreground">Experiment not found</h1>
          </div>
        </main>
      </div>
    );
  }

  // Prepare metadata description by stripping HTML and truncating
  const metaDescription = stripHtml(experiment.short_description || experiment.description).slice(0, 160);
  
  // Prepare structured data
  const structuredData = {
    "@context": "https://schema.org",
    "@type": "Course",
    "name": experiment.title,
    "description": metaDescription,
    "provider": {
      "@type": "Organization",
      "name": "NoCodeLab",
      "url": "https://nocodelab.ai"
    },
    "educationalLevel": experiment.level,
    "about": experiment.category,
    "isAccessibleForFree": !experiment.is_premium
  };

  return (
    <div className="min-h-screen bg-background">
      <Helmet>
        <title>{`${experiment.title} | NoCodeLab Experiments`}</title>
        <meta name="description" content={metaDescription} />
        
        {/* Open Graph tags */}
        <meta property="og:title" content={experiment.title} />
        <meta property="og:description" content={metaDescription} />
        <meta property="og:type" content="website" />
        {experiment.image_url && <meta property="og:image" content={experiment.image_url} />}
        
        {/* Twitter Card tags */}
        <meta name="twitter:card" content="summary_large_image" />
        <meta name="twitter:title" content={experiment.title} />
        <meta name="twitter:description" content={metaDescription} />
        {experiment.image_url && <meta name="twitter:image" content={experiment.image_url} />}
        
        {/* Keywords */}
        <meta name="keywords" content={`${experiment.category}, ${experiment.level}, no-code, development, experiment, tutorial, nocodelab, ${experiment.title.toLowerCase()}`} />
        
        {/* Structured Data */}
        <script type="application/ld+json">
          {JSON.stringify(structuredData)}
        </script>
      </Helmet>
      <ExperimentDetails experiment={experiment} />
    </div>
  );
};

export default ExperimentPage;
